@@ -2,13 +2,13 @@
 This module contains a SessionProperty class that can be used to add a
 SQLALchemy Session object to the context.
 
-This extension requires the SQLAlchemy module to be installed::
+This extension requires the SQLAlchemy module to be installed:
 
     $ pip install sqlalchemy
 
 The session is lazily initialized and closed at the end of every request.
 
-Example usage::
+Example usage:
 
     from rhino import Mapper, get
     from rhino.ext.sqlalchemy import SessionProperty
@@ -31,6 +31,10 @@ from __future__ import absolute_import
 from sqlalchemy import create_engine
 from sqlalchemy.orm import Session
 
+__all__ = [
+    'SessionProperty',
+]
+
 
 class SessionProperty(object):
     def __init__(self, url=None, delay_close=False, **session_args):
